"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
import pydantic
from squadcast_sdk.types import BaseModel
from typing import List
from typing_extensions import Annotated, TypedDict


class V4StatusPagesStatusPageComponentTypedDict(TypedDict):
    id: int
    name: str


class V4StatusPagesStatusPageComponent(BaseModel):
    id: int

    name: str


class V4StatusPagesStatusPageStatusTypedDict(TypedDict):
    id: int
    name: str
    color: str
    slug: str


class V4StatusPagesStatusPageStatus(BaseModel):
    id: int

    name: str

    color: str

    slug: str


class StatusMaintenanceTypedDict(TypedDict):
    id: int
    name: str
    color: str
    slug: str


class StatusMaintenance(BaseModel):
    id: int

    name: str

    color: str

    slug: str


class V4StatusPagesStatusPageTypedDict(TypedDict):
    id: int
    name: str
    is_public: bool
    domain_name: str
    custom_domain_name: str
    timezone: str
    logo_url: str
    components: List[V4StatusPagesStatusPageComponentTypedDict]
    is_custom_domain_enabled: bool
    is_custom_a_record_verified: bool
    is_custom_txt_verified: bool
    txt_record: str
    a_record: str
    subscribers_count: int
    status: V4StatusPagesStatusPageStatusTypedDict
    under_maintenance: bool
    status_maintenance: StatusMaintenanceTypedDict
    owner_type: str
    owner_id: str


class V4StatusPagesStatusPage(BaseModel):
    id: int

    name: str

    is_public: Annotated[bool, pydantic.Field(alias="isPublic")]

    domain_name: Annotated[str, pydantic.Field(alias="domainName")]

    custom_domain_name: Annotated[str, pydantic.Field(alias="customDomainName")]

    timezone: str

    logo_url: Annotated[str, pydantic.Field(alias="logoUrl")]

    components: List[V4StatusPagesStatusPageComponent]

    is_custom_domain_enabled: Annotated[
        bool, pydantic.Field(alias="isCustomDomainEnabled")
    ]

    is_custom_a_record_verified: Annotated[
        bool, pydantic.Field(alias="isCustomARecordVerified")
    ]

    is_custom_txt_verified: Annotated[bool, pydantic.Field(alias="isCustomTxtVerified")]

    txt_record: Annotated[str, pydantic.Field(alias="txtRecord")]

    a_record: Annotated[str, pydantic.Field(alias="aRecord")]

    subscribers_count: Annotated[int, pydantic.Field(alias="subscribersCount")]

    status: V4StatusPagesStatusPageStatus

    under_maintenance: Annotated[bool, pydantic.Field(alias="underMaintenance")]

    status_maintenance: Annotated[
        StatusMaintenance, pydantic.Field(alias="statusMaintenance")
    ]

    owner_type: Annotated[str, pydantic.Field(alias="ownerType")]

    owner_id: Annotated[str, pydantic.Field(alias="ownerID")]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
import pydantic
from squadcast_sdk.types import BaseModel
from typing import Literal, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


V4StatusPagesNewStatusPageComponentType = Literal[
    "component",
    "group",
]


class V4StatusPagesNewStatusPageComponentTypedDict(TypedDict):
    type: V4StatusPagesNewStatusPageComponentType
    name: str
    allow_subscription: bool
    description: NotRequired[str]
    service_id: NotRequired[str]


class V4StatusPagesNewStatusPageComponent(BaseModel):
    type: V4StatusPagesNewStatusPageComponentType

    name: str

    allow_subscription: Annotated[bool, pydantic.Field(alias="allowSubscription")]

    description: Optional[str] = None

    service_id: Annotated[Optional[str], pydantic.Field(alias="serviceID")] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing_extensions import TypedDict


class DedupKeyOverlayTypedDict(TypedDict):
    template: str
    duration: int


class DedupKeyOverlay(BaseModel):
    template: str

    duration: int


class V3ServicesOverlayUpdateDedupKeyOverlayRequestTypedDict(TypedDict):
    overlay_template_type: str
    dedup_key_overlay: DedupKeyOverlayTypedDict


class V3ServicesOverlayUpdateDedupKeyOverlayRequest(BaseModel):
    overlay_template_type: str

    dedup_key_overlay: DedupKeyOverlay



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class V3IncidentsNotesCreateNoteRequestTypedDict(TypedDict):
    r"""Request body for creating a new note."""

    message: str
    attachments: List[str]


class V3IncidentsNotesCreateNoteRequest(BaseModel):
    r"""Request body for creating a new note."""

    message: str

    attachments: List[str]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing import Literal
from typing_extensions import TypedDict


V3WorkflowsJiraCreateTicketName = Literal["jira_create_ticket",]


class V3WorkflowsJiraCreateTicketDataTypedDict(TypedDict):
    account: str
    project: str
    issue_type: str
    title: str
    description: str


class V3WorkflowsJiraCreateTicketData(BaseModel):
    account: str

    project: str

    issue_type: str

    title: str

    description: str


class V3WorkflowsJiraCreateTicketTypedDict(TypedDict):
    name: V3WorkflowsJiraCreateTicketName
    data: V3WorkflowsJiraCreateTicketDataTypedDict


class V3WorkflowsJiraCreateTicket(BaseModel):
    name: V3WorkflowsJiraCreateTicketName

    data: V3WorkflowsJiraCreateTicketData



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing import Any
from typing_extensions import TypedDict


class V3WorkflowsGetWorkflowActionByIDResponseTypedDict(TypedDict):
    id: int
    workflow_id: int
    name: str
    data: Any


class V3WorkflowsGetWorkflowActionByIDResponse(BaseModel):
    id: int

    workflow_id: int

    name: str

    data: Any



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing_extensions import TypedDict


class V3ServicesOverlayCustomContentTypedDict(TypedDict):
    message: str
    description: str


class V3ServicesOverlayCustomContent(BaseModel):
    message: str

    description: str



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_teams_abilities import V3TeamsAbilities, V3TeamsAbilitiesTypedDict
from squadcast_sdk.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class V3TeamsUpdateTeamRoleRequestTypedDict(TypedDict):
    name: NotRequired[str]
    abilities: NotRequired[V3TeamsAbilitiesTypedDict]


class V3TeamsUpdateTeamRoleRequest(BaseModel):
    name: Optional[str] = None

    abilities: Optional[V3TeamsAbilities] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_workflows_workflowapiresponse import (
    V3WorkflowsWorkflowAPIResponse,
    V3WorkflowsWorkflowAPIResponseTypedDict,
)
from squadcast_sdk.types import BaseModel
from typing_extensions import TypedDict


class V3WorkflowsGetWorkflowByIDResponseTypedDict(TypedDict):
    data: V3WorkflowsWorkflowAPIResponseTypedDict


class V3WorkflowsGetWorkflowByIDResponse(BaseModel):
    data: V3WorkflowsWorkflowAPIResponse



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
import pydantic
from squadcast_sdk.types import BaseModel
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class V3ServicesMaintenanceModeServiceMaintenanceTypedDict(TypedDict):
    maintenance_start_date: str
    daily: bool
    weekly: bool
    two_weekly: bool
    three_weekly: bool
    monthly: bool
    deleted: bool
    repeat_till: str
    maintenance_end_date: NotRequired[str]


class V3ServicesMaintenanceModeServiceMaintenance(BaseModel):
    maintenance_start_date: Annotated[str, pydantic.Field(alias="maintenanceStartDate")]

    daily: bool

    weekly: bool

    two_weekly: Annotated[bool, pydantic.Field(alias="twoWeekly")]

    three_weekly: Annotated[bool, pydantic.Field(alias="threeWeekly")]

    monthly: bool

    deleted: bool

    repeat_till: Annotated[str, pydantic.Field(alias="repeatTill")]

    maintenance_end_date: Annotated[
        Optional[str], pydantic.Field(alias="maintenanceEndDate")
    ] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_services_deduplicationrules_expressionbranch import (
    V3ServicesDeduplicationRulesExpressionBranch,
    V3ServicesDeduplicationRulesExpressionBranchTypedDict,
)
from squadcast_sdk.types import BaseModel
from typing import List, Literal, Optional
from typing_extensions import NotRequired, TypedDict


V3ServicesDeduplicationRulesDeduplicationRuleTimeUnit = Literal[
    "minute",
    "hour",
]


class V3ServicesDeduplicationRulesDeduplicationRuleTypedDict(TypedDict):
    expression: str
    time_window: int
    time_unit: V3ServicesDeduplicationRulesDeduplicationRuleTimeUnit
    is_basic: bool
    basic_expression: NotRequired[
        List[V3ServicesDeduplicationRulesExpressionBranchTypedDict]
    ]
    dependency_deduplication: NotRequired[bool]
    description: NotRequired[str]


class V3ServicesDeduplicationRulesDeduplicationRule(BaseModel):
    expression: str

    time_window: int

    time_unit: V3ServicesDeduplicationRulesDeduplicationRuleTimeUnit

    is_basic: bool

    basic_expression: Optional[List[V3ServicesDeduplicationRulesExpressionBranch]] = (
        None
    )

    dependency_deduplication: Optional[bool] = None

    description: Optional[str] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v4_statuspages_components_updatecomponentbyidrequest import (
    V4StatusPagesComponentsUpdateComponentByIDRequest,
    V4StatusPagesComponentsUpdateComponentByIDRequestTypedDict,
)
from .v4_statuspages_components_updatecomponentbyidresponse import (
    V4StatusPagesComponentsUpdateComponentByIDResponse,
    V4StatusPagesComponentsUpdateComponentByIDResponseTypedDict,
)
import pydantic
from squadcast_sdk.types import BaseModel
from squadcast_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class ComponentsUpdateComponentByIDRequestTypedDict(TypedDict):
    statuspage_id: str
    component_id: str
    v4_status_pages_components_update_component_by_id_request: (
        V4StatusPagesComponentsUpdateComponentByIDRequestTypedDict
    )


class ComponentsUpdateComponentByIDRequest(BaseModel):
    statuspage_id: Annotated[
        str,
        pydantic.Field(alias="statuspageID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    component_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    v4_status_pages_components_update_component_by_id_request: Annotated[
        V4StatusPagesComponentsUpdateComponentByIDRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]


class ComponentsUpdateComponentByIDResponseTypedDict(TypedDict):
    r"""The request has succeeded."""

    data: V4StatusPagesComponentsUpdateComponentByIDResponseTypedDict


class ComponentsUpdateComponentByIDResponse(BaseModel):
    r"""The request has succeeded."""

    data: V4StatusPagesComponentsUpdateComponentByIDResponse



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class UserTypedDict(TypedDict):
    id: str
    first_name: str
    last_name: str
    deleted: bool


class User(BaseModel):
    id: str

    first_name: str

    last_name: str

    deleted: bool


class V3IncidentsNotesNoteResponseTypedDict(TypedDict):
    r"""Represents a note associated with an incident."""

    id: str
    created_at: str
    updated_at: str
    organization_id: str
    incident_id: str
    user_id: str
    message: str
    type: str
    attachments: List[str]
    user: UserTypedDict
    replaced_message: str


class V3IncidentsNotesNoteResponse(BaseModel):
    r"""Represents a note associated with an incident."""

    id: str

    created_at: str

    updated_at: str

    organization_id: str

    incident_id: str

    user_id: str

    message: str

    type: str

    attachments: List[str]

    user: User

    replaced_message: str



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_teams_abilities import V3TeamsAbilities, V3TeamsAbilitiesTypedDict
from squadcast_sdk.types import BaseModel
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class V3TeamsTeamMemberResponseTypedDict(TypedDict):
    user_id: str
    role: NotRequired[str]
    role_ids: NotRequired[List[str]]
    abilities: NotRequired[V3TeamsAbilitiesTypedDict]


class V3TeamsTeamMemberResponse(BaseModel):
    user_id: str

    role: Optional[str] = None

    role_ids: Optional[List[str]] = None

    abilities: Optional[V3TeamsAbilities] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_services_taggingrules_createorupdatetaggingrulesrequest import (
    V3ServicesTaggingRulesCreateOrUpdateTaggingRulesRequest,
    V3ServicesTaggingRulesCreateOrUpdateTaggingRulesRequestTypedDict,
)
from .v3_services_taggingrules_taggingruleresponse import (
    V3ServicesTaggingRulesTaggingRuleResponse,
    V3ServicesTaggingRulesTaggingRuleResponseTypedDict,
)
import pydantic
from squadcast_sdk.types import BaseModel
from squadcast_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing import List
from typing_extensions import Annotated, TypedDict


class TaggingRulesCreateOrUpdateTaggingRulesRequestTypedDict(TypedDict):
    service_id: str
    v3_services_tagging_rules_create_or_update_tagging_rules_request: (
        V3ServicesTaggingRulesCreateOrUpdateTaggingRulesRequestTypedDict
    )


class TaggingRulesCreateOrUpdateTaggingRulesRequest(BaseModel):
    service_id: Annotated[
        str,
        pydantic.Field(alias="serviceID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    v3_services_tagging_rules_create_or_update_tagging_rules_request: Annotated[
        V3ServicesTaggingRulesCreateOrUpdateTaggingRulesRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]


class TaggingRulesCreateOrUpdateTaggingRulesDataTypedDict(TypedDict):
    rules: List[V3ServicesTaggingRulesTaggingRuleResponseTypedDict]


class TaggingRulesCreateOrUpdateTaggingRulesData(BaseModel):
    rules: List[V3ServicesTaggingRulesTaggingRuleResponse]


class TaggingRulesCreateOrUpdateTaggingRulesResponseTypedDict(TypedDict):
    r"""The request has succeeded and a new resource has been created as a result."""

    data: TaggingRulesCreateOrUpdateTaggingRulesDataTypedDict


class TaggingRulesCreateOrUpdateTaggingRulesResponse(BaseModel):
    r"""The request has succeeded and a new resource has been created as a result."""

    data: TaggingRulesCreateOrUpdateTaggingRulesData



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v4_statuspages_statuspagesubscribercomponent import (
    V4StatusPagesStatusPageSubscriberComponent,
    V4StatusPagesStatusPageSubscriberComponentTypedDict,
)
from datetime import datetime
import pydantic
from squadcast_sdk.types import BaseModel
from typing import List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class V4StatusPagesStatusPageSubscriberTypedDict(TypedDict):
    id: int
    type: str
    email_id: str
    webhook_url: str
    status: str
    subscribed_on: datetime
    component_list: NotRequired[
        List[V4StatusPagesStatusPageSubscriberComponentTypedDict]
    ]


class V4StatusPagesStatusPageSubscriber(BaseModel):
    id: int

    type: str

    email_id: Annotated[str, pydantic.Field(alias="emailID")]

    webhook_url: Annotated[str, pydantic.Field(alias="webhookURL")]

    status: str

    subscribed_on: Annotated[datetime, pydantic.Field(alias="subscribedOn")]

    component_list: Annotated[
        Optional[List[V4StatusPagesStatusPageSubscriberComponent]],
        pydantic.Field(alias="componentList"),
    ] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing import Literal, Optional
from typing_extensions import NotRequired, TypedDict


V3WorkflowsSlackCreateIncidentChannelUpdateName = Literal[
    "slack_create_incident_channel",
]


class V3WorkflowsSlackCreateIncidentChannelUpdateDataTypedDict(TypedDict):
    auto_name: NotRequired[bool]
    channel_name: NotRequired[str]


class V3WorkflowsSlackCreateIncidentChannelUpdateData(BaseModel):
    auto_name: Optional[bool] = None

    channel_name: Optional[str] = None


class V3WorkflowsSlackCreateIncidentChannelUpdateTypedDict(TypedDict):
    name: V3WorkflowsSlackCreateIncidentChannelUpdateName
    data: NotRequired[V3WorkflowsSlackCreateIncidentChannelUpdateDataTypedDict]


class V3WorkflowsSlackCreateIncidentChannelUpdate(BaseModel):
    name: V3WorkflowsSlackCreateIncidentChannelUpdateName

    data: Optional[V3WorkflowsSlackCreateIncidentChannelUpdateData] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v4_statuspages_maintenances_getmaintenancebyidresponse import (
    V4StatusPagesMaintenancesGetMaintenanceByIDResponse,
    V4StatusPagesMaintenancesGetMaintenanceByIDResponseTypedDict,
)
import pydantic
from squadcast_sdk.types import BaseModel
from squadcast_sdk.utils import FieldMetadata, PathParamMetadata
from typing_extensions import Annotated, TypedDict


class MaintenancesGetMaintenanceByIDRequestTypedDict(TypedDict):
    statuspage_id: str
    maintenance_id: str


class MaintenancesGetMaintenanceByIDRequest(BaseModel):
    statuspage_id: Annotated[
        str,
        pydantic.Field(alias="statuspageID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    maintenance_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]


class MaintenancesGetMaintenanceByIDResponseTypedDict(TypedDict):
    r"""The request has succeeded."""

    data: V4StatusPagesMaintenancesGetMaintenanceByIDResponseTypedDict


class MaintenancesGetMaintenanceByIDResponse(BaseModel):
    r"""The request has succeeded."""

    data: V4StatusPagesMaintenancesGetMaintenanceByIDResponse



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing_extensions import TypedDict


class UsersUpdateOrgLevelPermissionsResponseTypedDict(TypedDict):
    r"""The request has succeeded."""

    data: str


class UsersUpdateOrgLevelPermissionsResponse(BaseModel):
    r"""The request has succeeded."""

    data: str



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_services_deduplicationrules_deduplicationrule import (
    V3ServicesDeduplicationRulesDeduplicationRule,
    V3ServicesDeduplicationRulesDeduplicationRuleTypedDict,
)
from squadcast_sdk.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class V3ServicesDeduplicationRulesCreateDeduplicationRulesRequestTypedDict(TypedDict):
    rules: List[V3ServicesDeduplicationRulesDeduplicationRuleTypedDict]


class V3ServicesDeduplicationRulesCreateDeduplicationRulesRequest(BaseModel):
    rules: List[V3ServicesDeduplicationRulesDeduplicationRule]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing import List, Literal
from typing_extensions import TypedDict


V3WorkflowsSqMarkIncidentSLOAffectingName = Literal["sq_mark_incident_slo_affecting",]


class V3WorkflowsSqMarkIncidentSLOAffectingDataTypedDict(TypedDict):
    slis: List[str]
    slo: int


class V3WorkflowsSqMarkIncidentSLOAffectingData(BaseModel):
    slis: List[str]

    slo: int


class V3WorkflowsSqMarkIncidentSLOAffectingTypedDict(TypedDict):
    name: V3WorkflowsSqMarkIncidentSLOAffectingName
    data: V3WorkflowsSqMarkIncidentSLOAffectingDataTypedDict


class V3WorkflowsSqMarkIncidentSLOAffecting(BaseModel):
    name: V3WorkflowsSqMarkIncidentSLOAffectingName

    data: V3WorkflowsSqMarkIncidentSLOAffectingData



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v4_createscheduleoverriderequest import (
    V4CreateScheduleOverrideRequest,
    V4CreateScheduleOverrideRequestTypedDict,
)
from .v4_overrideresponse import V4OverrideResponse, V4OverrideResponseTypedDict
import pydantic
from squadcast_sdk.types import BaseModel
from squadcast_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class OverridesCreateScheduleOverrideRequestTypedDict(TypedDict):
    schedule_id: str
    v4_create_schedule_override_request: V4CreateScheduleOverrideRequestTypedDict


class OverridesCreateScheduleOverrideRequest(BaseModel):
    schedule_id: Annotated[
        str,
        pydantic.Field(alias="scheduleID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    v4_create_schedule_override_request: Annotated[
        V4CreateScheduleOverrideRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]


class OverridesCreateScheduleOverrideResponseTypedDict(TypedDict):
    r"""The request has succeeded and a new resource has been created as a result."""

    data: V4OverrideResponseTypedDict


class OverridesCreateScheduleOverrideResponse(BaseModel):
    r"""The request has succeeded and a new resource has been created as a result."""

    data: V4OverrideResponse



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .common_v3_rbacowner import CommonV3RBACOwner, CommonV3RBACOwnerTypedDict
from .v3_services_aptaconfig import V3ServicesAPTAConfig, V3ServicesAPTAConfigTypedDict
from .v3_services_escalationpolicybasic import (
    V3ServicesEscalationPolicyBasic,
    V3ServicesEscalationPolicyBasicTypedDict,
)
from .v3_services_iagconfig import V3ServicesIAGConfig, V3ServicesIAGConfigTypedDict
from .v3_services_jiracloudextension import (
    V3ServicesJiraCloudExtension,
    V3ServicesJiraCloudExtensionTypedDict,
)
from .v3_services_notificationdelayconfig import (
    V3ServicesNotificationDelayConfig,
    V3ServicesNotificationDelayConfigTypedDict,
)
from .v3_services_servicemaintainer import (
    V3ServicesServiceMaintainer,
    V3ServicesServiceMaintainerTypedDict,
)
from .v3_services_serviceslack import (
    V3ServicesServiceSlack,
    V3ServicesServiceSlackTypedDict,
)
from .v3_services_servicetag import V3ServicesServiceTag, V3ServicesServiceTagTypedDict
from datetime import datetime
from pydantic import model_serializer
from squadcast_sdk.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class ConfigTypedDict(TypedDict):
    dedup_key_enabled: bool


class Config(BaseModel):
    dedup_key_enabled: bool


class V3ServicesServiceResponseTypedDict(TypedDict):
    id: str
    name: str
    slug: str
    email: str
    escalation_policy_id: str
    organization_id: str
    api_key: str
    description: str
    owner: CommonV3RBACOwnerTypedDict
    r"""Represents the RBAC owner of an entity."""
    maintainer: V3ServicesServiceMaintainerTypedDict
    tags: List[V3ServicesServiceTagTypedDict]
    auto_pause_transient_alerts_config: V3ServicesAPTAConfigTypedDict
    intelligent_alerts_grouping_config: V3ServicesIAGConfigTypedDict
    delay_notification_config: V3ServicesNotificationDelayConfigTypedDict
    config: ConfigTypedDict
    created_at: datetime
    updated_at: datetime
    depends: NotRequired[Nullable[List[str]]]
    on_maintenance: NotRequired[bool]
    slack: NotRequired[V3ServicesServiceSlackTypedDict]
    escalation_policy: NotRequired[V3ServicesEscalationPolicyBasicTypedDict]
    r"""Represents the basic details of an Escalation Policy for a service."""
    jira_cloud: NotRequired[V3ServicesJiraCloudExtensionTypedDict]


class V3ServicesServiceResponse(BaseModel):
    id: str

    name: str

    slug: str

    email: str

    escalation_policy_id: str

    organization_id: str

    api_key: str

    description: str

    owner: CommonV3RBACOwner
    r"""Represents the RBAC owner of an entity."""

    maintainer: V3ServicesServiceMaintainer

    tags: List[V3ServicesServiceTag]

    auto_pause_transient_alerts_config: V3ServicesAPTAConfig

    intelligent_alerts_grouping_config: V3ServicesIAGConfig

    delay_notification_config: V3ServicesNotificationDelayConfig

    config: Config

    created_at: datetime

    updated_at: datetime

    depends: OptionalNullable[List[str]] = UNSET

    on_maintenance: Optional[bool] = None

    slack: Optional[V3ServicesServiceSlack] = None

    escalation_policy: Optional[V3ServicesEscalationPolicyBasic] = None
    r"""Represents the basic details of an Escalation Policy for a service."""

    jira_cloud: Optional[V3ServicesJiraCloudExtension] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "depends",
            "on_maintenance",
            "slack",
            "escalation_policy",
            "jira_cloud",
        ]
        nullable_fields = ["depends"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_workflows_actionrequestupdate import (
    V3WorkflowsActionRequestUpdate,
    V3WorkflowsActionRequestUpdateTypedDict,
)
import pydantic
from squadcast_sdk.types import BaseModel
from squadcast_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class WorkflowsUpdateWorkflowActionRequestTypedDict(TypedDict):
    workflow_id: str
    action_id: str
    v3_workflows_action_request_update: V3WorkflowsActionRequestUpdateTypedDict


class WorkflowsUpdateWorkflowActionRequest(BaseModel):
    workflow_id: Annotated[
        str,
        pydantic.Field(alias="workflowID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    action_id: Annotated[
        str,
        pydantic.Field(alias="actionID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    v3_workflows_action_request_update: Annotated[
        V3WorkflowsActionRequestUpdate,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing_extensions import TypedDict


class V3ServicesServiceSlackTypedDict(TypedDict):
    channel_id: str
    name: str
    time: int


class V3ServicesServiceSlack(BaseModel):
    channel_id: str

    name: str

    time: int



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_workflows_componentandimpact import (
    V3WorkflowsComponentAndImpact,
    V3WorkflowsComponentAndImpactTypedDict,
)
from .v3_workflows_issuestatusandmessage import (
    V3WorkflowsIssueStatusAndMessage,
    V3WorkflowsIssueStatusAndMessageTypedDict,
)
from squadcast_sdk.types import BaseModel
from typing import List, Literal
from typing_extensions import TypedDict


V3WorkflowsSqCreateStatusPageIssueName = Literal["sq_add_status_page_issue",]


class V3WorkflowsSqCreateStatusPageIssueDataTypedDict(TypedDict):
    component_and_impact: List[V3WorkflowsComponentAndImpactTypedDict]
    issue_title: str
    page_status_id: int
    status_and_message: List[V3WorkflowsIssueStatusAndMessageTypedDict]
    status_page_id: int


class V3WorkflowsSqCreateStatusPageIssueData(BaseModel):
    component_and_impact: List[V3WorkflowsComponentAndImpact]

    issue_title: str

    page_status_id: int

    status_and_message: List[V3WorkflowsIssueStatusAndMessage]

    status_page_id: int


class V3WorkflowsSqCreateStatusPageIssueTypedDict(TypedDict):
    name: V3WorkflowsSqCreateStatusPageIssueName
    data: V3WorkflowsSqCreateStatusPageIssueDataTypedDict


class V3WorkflowsSqCreateStatusPageIssue(BaseModel):
    name: V3WorkflowsSqCreateStatusPageIssueName

    data: V3WorkflowsSqCreateStatusPageIssueData



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from typing import Literal


V3IncidentsIncidentExportRequestIsStarred = Literal[
    "yes",
    "no",
]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class V3SquadsCreateSquadRequestTypedDict(TypedDict):
    name: str
    members: List[str]
    owner_id: str


class V3SquadsCreateSquadRequest(BaseModel):
    name: str

    members: List[str]

    owner_id: str



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_teams_teamresponse import V3TeamsTeamResponse, V3TeamsTeamResponseTypedDict
from squadcast_sdk.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class TeamsGetAllTeamsResponseTypedDict(TypedDict):
    r"""The request has succeeded."""

    data: List[V3TeamsTeamResponseTypedDict]


class TeamsGetAllTeamsResponse(BaseModel):
    r"""The request has succeeded."""

    data: List[V3TeamsTeamResponse]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_workflows_workflowapiresponse import (
    V3WorkflowsWorkflowAPIResponse,
    V3WorkflowsWorkflowAPIResponseTypedDict,
)
from squadcast_sdk.types import BaseModel
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class ACLTypedDict(TypedDict):
    pass


class ACL(BaseModel):
    pass


class V3WorkflowsListWorkflowAPIResponseMetaTypedDict(TypedDict):
    total_count: int
    acl: NotRequired[ACLTypedDict]


class V3WorkflowsListWorkflowAPIResponseMeta(BaseModel):
    total_count: int

    acl: Optional[ACL] = None


class V3WorkflowsListWorkflowAPIResponseTypedDict(TypedDict):
    data: List[V3WorkflowsWorkflowAPIResponseTypedDict]
    meta: V3WorkflowsListWorkflowAPIResponseMetaTypedDict


class V3WorkflowsListWorkflowAPIResponse(BaseModel):
    data: List[V3WorkflowsWorkflowAPIResponse]

    meta: V3WorkflowsListWorkflowAPIResponseMeta



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_incidents_tags_incidentfortagsresponse import (
    V3IncidentsTagsIncidentForTagsResponse,
    V3IncidentsTagsIncidentForTagsResponseTypedDict,
)
from .v3_incidents_tags_updatetagrequest import (
    V3IncidentsTagsUpdateTagRequest,
    V3IncidentsTagsUpdateTagRequestTypedDict,
)
import pydantic
from squadcast_sdk.types import BaseModel
from squadcast_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class TagsUpdateTagRequestTypedDict(TypedDict):
    incident_id: str
    v3_incidents_tags_update_tag_request: V3IncidentsTagsUpdateTagRequestTypedDict


class TagsUpdateTagRequest(BaseModel):
    incident_id: Annotated[
        str,
        pydantic.Field(alias="IncidentId"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    v3_incidents_tags_update_tag_request: Annotated[
        V3IncidentsTagsUpdateTagRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]


class TagsUpdateTagResponseTypedDict(TypedDict):
    r"""The request has succeeded."""

    data: V3IncidentsTagsIncidentForTagsResponseTypedDict


class TagsUpdateTagResponse(BaseModel):
    r"""The request has succeeded."""

    data: V3IncidentsTagsIncidentForTagsResponse



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
import pydantic
from squadcast_sdk.types import BaseModel
from squadcast_sdk.utils import FieldMetadata, PathParamMetadata
from typing_extensions import Annotated, TypedDict


class NotesDeleteNoteRequestTypedDict(TypedDict):
    incident_id: str
    r"""Required"""
    note_id: str
    r"""Required"""


class NotesDeleteNoteRequest(BaseModel):
    incident_id: Annotated[
        str,
        pydantic.Field(alias="IncidentId"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]
    r"""Required"""

    note_id: Annotated[
        str,
        pydantic.Field(alias="NoteId"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]
    r"""Required"""


class NotesDeleteNoteResponseBodyTypedDict(TypedDict):
    r"""There is no content to send for this request, but the headers may be useful."""


class NotesDeleteNoteResponseBody(BaseModel):
    r"""There is no content to send for this request, but the headers may be useful."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_incidents_apta_messageresponse import (
    V3IncidentsAptaMessageResponse,
    V3IncidentsAptaMessageResponseTypedDict,
)
import pydantic
from squadcast_sdk.types import BaseModel
from squadcast_sdk.utils import FieldMetadata, PathParamMetadata
from typing_extensions import Annotated, TypedDict


class AptaMarkAsTransientRequestTypedDict(TypedDict):
    incident_id: str


class AptaMarkAsTransientRequest(BaseModel):
    incident_id: Annotated[
        str,
        pydantic.Field(alias="incidentID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]


class AptaMarkAsTransientResponseTypedDict(TypedDict):
    r"""The request has succeeded."""

    data: V3IncidentsAptaMessageResponseTypedDict


class AptaMarkAsTransientResponse(BaseModel):
    r"""The request has succeeded."""

    data: V3IncidentsAptaMessageResponse



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing import Literal, Optional
from typing_extensions import NotRequired, TypedDict


V3WorkflowsSlackMessageUserUpdateName = Literal["slack_message_user",]


class V3WorkflowsSlackMessageUserUpdateDataTypedDict(TypedDict):
    member_id: NotRequired[str]
    message: NotRequired[str]


class V3WorkflowsSlackMessageUserUpdateData(BaseModel):
    member_id: Optional[str] = None

    message: Optional[str] = None


class V3WorkflowsSlackMessageUserUpdateTypedDict(TypedDict):
    name: V3WorkflowsSlackMessageUserUpdateName
    data: NotRequired[V3WorkflowsSlackMessageUserUpdateDataTypedDict]


class V3WorkflowsSlackMessageUserUpdate(BaseModel):
    name: V3WorkflowsSlackMessageUserUpdateName

    data: Optional[V3WorkflowsSlackMessageUserUpdateData] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_webforms_recaptchasecrets import (
    V3WebformsRecaptchaSecrets,
    V3WebformsRecaptchaSecretsTypedDict,
)
from .v3_webforms_wfinputfield import (
    V3WebformsWFInputField,
    V3WebformsWFInputFieldTypedDict,
)
from .v3_webforms_wfservice import V3WebformsWFService, V3WebformsWFServiceTypedDict
from squadcast_sdk.types import BaseModel
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class V3WebformsWebformResponseTagsTypedDict(TypedDict):
    pass


class V3WebformsWebformResponseTags(BaseModel):
    pass


class V3WebformsWebformResponseTypedDict(TypedDict):
    id: int
    org_id: str
    owner_id: str
    name: str
    is_cname: bool
    public_url: str
    tags: V3WebformsWebformResponseTagsTypedDict
    is_captcha_enabled: bool
    captcha_provider: str
    captcha_secret: V3WebformsRecaptchaSecretsTypedDict
    r"""reCAPTCHA credentials to be validated"""
    form_owner_type: str
    form_owner_id: str
    form_owner_name: str
    services: List[V3WebformsWFServiceTypedDict]
    input_field: List[V3WebformsWFInputFieldTypedDict]
    header: str
    title: str
    footer_text: str
    footer_link: str
    email_on: List[str]
    incident_count: int
    mttr: float
    is_deleted: bool
    deleted_at: str
    host_name: NotRequired[str]
    logo_url: NotRequired[str]
    description: NotRequired[str]


class V3WebformsWebformResponse(BaseModel):
    id: int

    org_id: str

    owner_id: str

    name: str

    is_cname: bool

    public_url: str

    tags: V3WebformsWebformResponseTags

    is_captcha_enabled: bool

    captcha_provider: str

    captcha_secret: V3WebformsRecaptchaSecrets
    r"""reCAPTCHA credentials to be validated"""

    form_owner_type: str

    form_owner_id: str

    form_owner_name: str

    services: List[V3WebformsWFService]

    input_field: List[V3WebformsWFInputField]

    header: str

    title: str

    footer_text: str

    footer_link: str

    email_on: List[str]

    incident_count: int

    mttr: float

    is_deleted: bool

    deleted_at: str

    host_name: Optional[str] = None

    logo_url: Optional[str] = None

    description: Optional[str] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v4_statuspages_issues_componentstatus import (
    V4StatusPagesIssuesComponentStatus,
    V4StatusPagesIssuesComponentStatusTypedDict,
)
import pydantic
from squadcast_sdk.types import BaseModel
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class V4StatusPagesIssuesIssueComponentDetailTypedDict(TypedDict):
    id: NotRequired[int]
    status: NotRequired[V4StatusPagesIssuesComponentStatusTypedDict]
    under_maintenance: NotRequired[bool]
    status_maintenance: NotRequired[V4StatusPagesIssuesComponentStatusTypedDict]


class V4StatusPagesIssuesIssueComponentDetail(BaseModel):
    id: Optional[int] = None

    status: Optional[V4StatusPagesIssuesComponentStatus] = None

    under_maintenance: Annotated[
        Optional[bool], pydantic.Field(alias="underMaintenance")
    ] = None

    status_maintenance: Annotated[
        Optional[V4StatusPagesIssuesComponentStatus],
        pydantic.Field(alias="statusMaintenance"),
    ] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class V3WorkflowsTagTypedDict(TypedDict):
    color: NotRequired[str]
    key: NotRequired[str]
    value: NotRequired[str]


class V3WorkflowsTag(BaseModel):
    color: Optional[str] = None

    key: Optional[str] = None

    value: Optional[str] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_services_routingrules_expressionbranch import (
    V3ServicesRoutingRulesExpressionBranch,
    V3ServicesRoutingRulesExpressionBranchTypedDict,
)
from squadcast_sdk.types import BaseModel
from typing import List, Literal, Optional
from typing_extensions import NotRequired, TypedDict


V3ServicesRoutingRulesRoutingRuleResponseEntityType = Literal[
    "user",
    "squad",
    "escalation_policy",
]


class V3ServicesRoutingRulesRoutingRuleResponseRouteToTypedDict(TypedDict):
    entity_type: V3ServicesRoutingRulesRoutingRuleResponseEntityType
    entity_id: str


class V3ServicesRoutingRulesRoutingRuleResponseRouteTo(BaseModel):
    entity_type: V3ServicesRoutingRulesRoutingRuleResponseEntityType

    entity_id: str


class V3ServicesRoutingRulesRoutingRuleResponseTypedDict(TypedDict):
    expression: str
    route_to: V3ServicesRoutingRulesRoutingRuleResponseRouteToTypedDict
    is_basic: bool
    basic_expression: NotRequired[List[V3ServicesRoutingRulesExpressionBranchTypedDict]]


class V3ServicesRoutingRulesRoutingRuleResponse(BaseModel):
    expression: str

    route_to: V3ServicesRoutingRulesRoutingRuleResponseRouteTo

    is_basic: bool

    basic_expression: Optional[List[V3ServicesRoutingRulesExpressionBranch]] = None
